@@ -3,7 +3,7 @@ mpcx_tree
 
 high-level functions working with trees of polynomials
 
-Copyright (C) 2009, 2010, 2011, 2012 Andreas Enge
+Copyright (C) 2009, 2010, 2011, 2012, 2020 Andreas Enge
 
 This file is part of the MPFRCX Library.
 
@@ -176,9 +176,12 @@ void mpcx_multieval (mpc_t *values, mpc_t *args, int no, mpcx_srcptr f) {
    int chunks, size;
    int i;
 
-   chunks = (2 * no) / f->deg;
-   if (chunks == 0)
+   if (f->deg <= 1)
+      chunks = no;
+   else if (f->deg > 2 * no)
       chunks = 1;
+   else
+      chunks = (2 * no) / f->deg;
    size = no / chunks;
 
    for (i = 0; i < chunks - 1; i++)
