@@ -3,7 +3,7 @@ mpfrcx_get_version
 
 MPFRCX version
 
-Copyright (C) 2010, 2011, 2012, 2013, 2018 Andreas Enge
+Copyright (C) 2010, 2011, 2012, 2013, 2018, 2020, 2021 Andreas Enge
 
 This file is part of the MPFRCX Library.
 
@@ -26,5 +26,5 @@ MA 02111-1307, USA.
 #include "mpfrcx-impl.h"
 
 const char * mpfrcx_get_version (void) {
-  return "0.5";
+  return "0.6.3";
 }
